@@ -1,5 +1,5 @@
 package Yancy::Plugin::Editor;
-our $VERSION = '1.078';
+our $VERSION = '1.079';
 # ABSTRACT: Yancy content editor, admin, and management application
 
 #pod =head1 SYNOPSIS
@@ -571,8 +571,20 @@ sub _openapi_spec_from_schema {
                     201 => {
                         description => $self->app->l( 'OpenAPI create response' ),
                         schema => {
-                            '$ref' => '#' . join '/', map { url_escape $_ } 'definitions',
-                                      $schema_name, 'properties', @id_fields,
+                            @id_fields > 1
+                            ? (
+                                type => 'array',
+                                items => [
+                                    map +{
+                                        '$ref' => '#/' . join '/', map { url_escape $_ }
+                                            'definitions', $schema_name, 'properties', $_,
+                                    }, @id_fields,
+                                ],
+                            )
+                            : (
+                                '$ref' => '#/' . join '/', map { url_escape $_ }
+                                    'definitions', $schema_name, 'properties', $id_fields[0],
+                            ),
                         },
                     },
                     default => {
@@ -696,7 +708,7 @@ Yancy::Plugin::Editor - Yancy content editor, admin, and management application
 
 =head1 VERSION
 
-version 1.078
+version 1.079
 
 =head1 SYNOPSIS
 
