@@ -1,5 +1,5 @@
 package Yancy::Util;
-our $VERSION = '1.078';
+our $VERSION = '1.079';
 # ABSTRACT: Utilities for Yancy
 
 #pod =head1 SYNOPSIS
@@ -499,12 +499,7 @@ sub derp(@) {
 
 sub json_validator {
     my ( $schema ) = @_;
-    my $v = JSON::Validator->new(
-        # This fixes HTML forms submitting the string "20" not being
-        # detected as a number, or the number 1 not being detected as
-        # a boolean
-        coerce => { booleans => 1, numbers => 1, strings => 1 },
-    );
+    my $v = JSON::Validator->new( coerce => 'bool,def,num,str' );
     my $formats = $v->formats;
     $formats->{ password } = sub { undef };
     $formats->{ filepath } = sub { undef };
@@ -526,7 +521,7 @@ Yancy::Util - Utilities for Yancy
 
 =head1 VERSION
 
-version 1.078
+version 1.079
 
 =head1 SYNOPSIS
 
