@@ -1,6 +1,6 @@
 DROP TABLE IF EXISTS pages;
 CREATE TABLE pages (
-    pages_id SERIAL PRIMARY KEY,
+    page_id SERIAL PRIMARY KEY,
     title VARCHAR(255) NOT NULL,
     slug VARCHAR(255) NOT NULL,
     content TEXT,
